use strict;
use warnings;
package Test::Path::Resolver::DS;
our $VERSION = '3.100450';
use Data::Section -setup;

1;
__DATA__
__[ raven.txt ]__
Once upon a midnight dreary, while I pondered, weak and weary,
Over many a quaint and curious volume of forgotten lore,
While I nodded, nearly napping, suddenly there came a tapping,
As of some one gently rapping, rapping at my chamber door.
"'Tis some visitor," I muttered, "tapping at my chamber door —
     Only this, and nothing more."
__[ data.txt ]__
Resolver of type data
__[ quotes/raven.txt ]__
Nevermore!
__[ now.playing ]__
Omaha by Counting Crows
